/*
 * Copyright 2010 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.api.internal.tasks.execution

import org.gradle.api.internal.TaskInternal
import org.gradle.api.internal.tasks.TaskExecuter
import org.gradle.api.internal.tasks.TaskExecutionContext
import org.gradle.api.internal.tasks.TaskStateInternal
import spock.lang.Specification

class ExecuteAtMostOnceTaskExecuterTest extends Specification {
    private final TaskExecuter target = Mock(TaskExecuter)
    private final TaskInternal task = Mock(TaskInternal)
    private final TaskStateInternal state = Mock(TaskStateInternal)
    private final TaskExecutionContext executionContext = Mock(TaskExecutionContext)
    private final ExecuteAtMostOnceTaskExecuter executer = new ExecuteAtMostOnceTaskExecuter(target)

    def doesNothingWhenTaskHasAlreadyBeenExecuted() {
        when:
        executer.execute(task, state, executionContext)

        then:
        1 * state.getExecuted() >> true
        0 * _
    }

    def delegatesToExecuterWhenTaskHasNotBeenExecuted() {
        when:
        executer.execute(task, state, executionContext)

        then:
        1 * state.getExecuted() >> false
        1 * target.execute(task, state, executionContext)

        then:
        0 * _
    }
}
